@@ -9,7 +9,7 @@ def test_ocrmypdf():
     converter = OCRmyPDFConverter()
     parameters = OCRmyPDFParameters()
     testdir = Path(__file__).parent
-    source = Path(testdir, 'data/1 - BORALEX .pdf')
+    source = Path(testdir, 'data/PB-Scanned.pdf')
     with source.open("rb") as fin:
         docs: List[Document] = converter.convert(UploadFile(source.name, fin, 'application/pdf'), parameters)
         assert len(docs) == 1
